#
# spec file for package opensuse-welcome
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __builder ninja
%define _name openSUSE-welcome

Name:           opensuse-welcome
Version:        0.1.9+git.0.66be0d8
Release:        bp154.2.6.1
Summary:        Welcome utility for openSUSE
License:        GPL-3.0-or-later AND MIT
Group:          System/X11/Utilities
URL:            https://github.com/openSUSE/openSUSE-welcome
Source0:        %{_name}-%{version}.tar.xz
# Source file to produce opensuse-welcome-lang.inc
Source98:       opensuse-welcome-lang-recommends.sh
# REcommend the lang package based on installed locales
# the -lang package actually does not install the translations
# to a standard location, which results in the lang not having the
# relevant supplements added.
Source99:       opensuse-welcome-lang.inc
Patch0:         0001-panellayouter-use-QTemporaryFile-for-applyLayout-bsc.patch
BuildRequires:  hicolor-icon-theme
BuildRequires:  hicolor-icon-theme-branding-openSUSE
BuildRequires:  libqt5-linguist
BuildRequires:  meson
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5WebChannel)
BuildRequires:  pkgconfig(Qt5WebEngine)
%include %{SOURCE99}

%lang_package

%description
A welcome utility built to welcome new users to openSUSE.

%prep
%setup -q -n %{_name}-%{version}
%patch0 -p1

%build
%meson
%meson_build

%install
%meson_install

%files
%license LICENSE
%doc README.md
%{_bindir}/opensuse-welcome
%{_datadir}/applications/org.opensuse.opensuse_welcome.desktop
%{_sysconfdir}/xdg/autostart/org.opensuse.opensuse_welcome.desktop
%{_datadir}/icons/hicolor/scalable/apps/org.opensuse.opensuse_welcome.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.opensuse.opensuse_welcome-symbolic.svg
%{_datadir}/metainfo/org.opensuse.opensuse_welcome.appdata.xml

%files lang
%{_datadir}/openSUSE-Welcome/

%changelog
* Fri Aug 11 2023 Matthias Gerstner <matthias.gerstner@suse.com>
- 0001-panellayouter-use-QTemporaryFile-for-applyLayout-bsc.patch: fix
  possible security issues when using the feature to change the Xfce
  desktop layout, caused by a fixed temporary file path used in /tmp/layout
  (bsc#1213708, CVE-2023-32184).
* Mon Sep 19 2022 tux93@opensuse.org
- Update to version 0.1.9+git.0.66be0d8:
  * fix: it's called Plasma
  * fix: make openSUSE welcome work again (boo#1194380)
  * fix: undead the URLs to Telegram groups
  * Translation updates
* Tue May 31 2022 dimstar@opensuse.org
- Update to version 0.1.8+git.46.64e51ec:
  + Updated translations (Catalan, Russian, Swedish, Ukrainian).
- Add back -lang recommends to the main package: the -lang package
  does not follow the standard method of installing translations to
  /usr/share/locale, but installs everything to
  /usr/share/opensuse-welcome. As such, the automatic supplements
  do not trigger as intended. A opensuse-welcome-lang.inc is being
  generated to make the recommends still smarter, based on selected
  locales in zypp.
* Tue May 24 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not recommend lang package: the lang package has smarter
  supplements in place.
* Sun Feb  6 2022 opensuse.lietuviu.kalba@gmail.com
- Update to version 0.1.8+git.44.7923e16:
  * Added Lithuanian translation using Weblate
* Thu Feb  3 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 0.1.8+git.40.95061c3
  * Translation updates
- Add _service to get latest source + translations from git,
  fixes boo#1185893
* Sat May 30 2020 Carson Black <uhhadd@gmail.com>
- Update to 0.1.8
* Tue Oct  1 2019 Carson Black <uhhadd@gmail.com>
- Update to 0.1.7.1
- Way more translations have been added.
- The available translations are now:
  * Catalan
  * Chinese (China)
  * Czech
  * Dutch
  * French
  * German
  * Italian [45.1%%]
  * Japanese
  * Polish
  * Portuguese (Brazil)
  * Russian [51.2%%]
  - Spanish
* Wed Aug 21 2019 Carson Black <uhhadd@gmail.com>
- Update to 0.1.6
- More translations, woo-hoo
- Fix bug where launching a help program causes the program to freeze
* Sun Jul 21 2019 Carson Black <uhhadd@gmail.com>
- Update to 0.1.5
- Translations are bundled outside of the binary now
- Messages are no longer spammed to console when running from terminal
- Unneeded and unused things removed for a smaller binary
- Mastodon social media now listed
- Subpackage translations
* Sat Jul 13 2019 Carson Black <uhhadd@gmail.com>
- Update to 1.4
- Even better RSS security
- Spanish translation
* Wed Jul 10 2019 Carson Black <uhhadd@gmail.com>
- Update to 1.3
- Fix license (again)
- Improved metadata (appstream, reverse dns)
- New icon
- Better RSS security
* Wed Jul 10 2019 Carson Black <uhhadd@gmail.com>
- fix naming issue pointed out by factory-auto
- fix license to match LICENSE file
* Fri Jun 21 2019 Carson Black <uhhadd@gmail.com>
- update to version 0.1.2
- files now have license headers
* Thu Jun 20 2019 Carson Black <uhhadd@gmail.com>
- update to version 0.1.1
- cmake installs desktop files now
- uses ninja now too
* Tue Jun  4 2019 Carson Black <uhhadd@gmail.com>
- looks like we're hopping back down some versions to 0.1.0, openSUSE Leap style
- move to openSUSE github
* Thu May 23 2019 Carson Black <uhhadd@gmail.com>
- Update to version 0.5
- Copy desktop files to needed locations
* Wed May 22 2019 Carson Black <uhhadd@gmail.com>
- update to version 0.2
* Tue May 21 2019 Carson Black <uhhadd@gmail.com>
- initial version
